@@ -18,6 +18,7 @@
 #include <kscreen/edid.h>
 #include <kscreen/getconfigoperation.h>
 #include <kscreen/mode.h>
+#include <kscreen/screen.h>
 #include <kscreen/types.h>
 
 static QTextStream cout(stdout);
@@ -54,12 +55,8 @@ void Console::printConfig()
         return;
     }
 
-    connect(m_config.data(), &Config::primaryOutputChanged, [&](const OutputPtr &output) {
-        if (output) {
-            qDebug() << "New primary output: " << output->id() << output->name();
-        } else {
-            qDebug() << "No primary output.";
-        }
+    connect(m_config.data(), &Config::prioritiesChanged, [&]() {
+        qDebug() << "Priorities changed:" << m_config.data()->outputs();
     });
 
     qDebug() << "Screen:";
@@ -67,8 +64,8 @@ void Console::printConfig()
     qDebug() << "\tminSize:" << m_config->screen()->minSize();
     qDebug() << "\tcurrentSize:" << m_config->screen()->currentSize();
 
-    OutputList outputs = m_config->outputs();
-    Q_FOREACH (const OutputPtr &output, outputs) {
+    const OutputList outputs = m_config->outputs();
+    for (const OutputPtr &output : outputs) {
         qDebug() << "\n-----------------------------------------------------\n";
         qDebug() << "Id: " << output->id();
         qDebug() << "Name: " << output->name();
@@ -78,7 +75,7 @@ void Console::printConfig()
             continue;
         }
         qDebug() << "Enabled: " << output->isEnabled();
-        qDebug() << "Primary: " << output->isPrimary();
+        qDebug() << "Priority: " << output->priority();
         qDebug() << "Rotation: " << output->rotation();
         qDebug() << "Pos: " << output->pos();
         qDebug() << "MMSize: " << output->sizeMm();
@@ -98,8 +95,8 @@ void Console::printConfig()
         qDebug() << "Preferred modes: " << output->preferredModes();
         qDebug() << "Modes: ";
 
-        ModeList modes = output->modes();
-        Q_FOREACH (const ModePtr &mode, modes) {
+        const ModeList modes = output->modes();
+        for (const ModePtr &mode : modes) {
             qDebug() << "\t" << mode->id() << "  " << mode->name() << " " << mode->size() << " " << mode->refreshRate();
         }
 
@@ -137,24 +134,22 @@ void Console::printSerializations()
     qDebug() << "Configs in: " << path;
 
     QDir dir(path);
-    QStringList files = dir.entryList(QDir::Files);
+    const QStringList files = dir.entryList(QDir::Files);
     qDebug() << "Number of files: " << files.count() << Qt::endl;
 
     QJsonDocument parser;
-    Q_FOREACH (const QString fileName, files) {
+    for (const QString &fileName : files) {
         QJsonParseError error;
         qDebug() << fileName;
         QFile file(path + QLatin1Char('/') + fileName);
         file.open(QFile::ReadOnly);
-        parser.fromJson(file.readAll(), &error);
+        QJsonDocument parser = QJsonDocument::fromJson(file.readAll(), &error);
         if (error.error != QJsonParseError::NoError) {
-            qDebug() << "    "
-                     << "can't parse file";
+            qDebug() << "    can't parse file:";
             qDebug() << "    " << error.errorString();
-            continue;
+        } else {
+            qDebug().noquote() << parser.toJson(QJsonDocument::Indented);
         }
-
-        qDebug() << parser.toJson(QJsonDocument::Indented) << Qt::endl;
     }
 }
 
