@@ -8,6 +8,10 @@
 #include "kcm_screen_debug.h"
 #include "output_model.h"
 
+#include <algorithm>
+#include <cstdint>
+#include <utility>
+
 #include <kscreen/configmonitor.h>
 #include <kscreen/getconfigoperation.h>
 #include <kscreen/output.h>
@@ -45,8 +49,12 @@ void ConfigHandler::setConfig(KScreen::ConfigPtr config)
     m_initialRetention = getRetention();
     Q_EMIT retentionChanged();
 
-    connect(m_outputModel, &OutputModel::changed, this, [this]() {
-        checkNeedsSave();
+    connect(m_outputModel, &OutputModel::dataChanged, this, [this](const QModelIndex &topLeft, const QModelIndex &bottomRight, const QVector<int> &roles) {
+        Q_UNUSED(bottomRight)
+        // Do not run checks during interactive reaarange
+        if (!m_outputModel->isMoving()) {
+            checkNeedsSave();
+        }
         Q_EMIT changed();
     });
     connect(m_config.data(), &KScreen::Config::outputAdded, this, [this]() {
@@ -55,33 +63,16 @@ void ConfigHandler::setConfig(KScreen::ConfigPtr config)
     connect(m_config.data(), &KScreen::Config::outputRemoved, this, [this]() {
         Q_EMIT outputConnect(false);
     });
-    connect(m_config.data(), &KScreen::Config::primaryOutputChanged, this, &ConfigHandler::primaryOutputChanged);
+    connect(m_config.data(), &KScreen::Config::prioritiesChanged, this, &ConfigHandler::outputPrioritiesChanged);
 
     Q_EMIT outputModelChanged();
 }
 
-void ConfigHandler::resetScale(const KScreen::OutputPtr &output)
-{
-    // Load scale control (either not set, same or windowing system does not transmit scale).
-    const qreal scale = m_control->getScale(output);
-    if (scale > 0) {
-        output->setScale(scale);
-        const auto outputs = m_initialConfig->outputs();
-        for (auto initialOutput : outputs) {
-            if (initialOutput->id() == output->id()) {
-                initialOutput->setScale(scale);
-                break;
-            }
-        }
-    }
-}
-
 void ConfigHandler::initOutput(const KScreen::OutputPtr &output)
 {
     output->setExplicitLogicalSize(config()->logicalSizeForOutput(*output));
 
     if (output->isConnected()) {
-        resetScale(output);
         m_outputModel->add(output);
     }
     connect(output.data(), &KScreen::Output::isConnectedChanged, this, [this, output]() {
@@ -98,10 +89,6 @@ void ConfigHandler::updateInitialData()
             return;
         }
         m_initialConfig = qobject_cast<GetConfigOperation *>(op)->config();
-        const auto outputs = m_config->outputs();
-        for (const auto &output : outputs) {
-            resetScale(output);
-        }
         m_initialControl.reset(new ControlConfig(m_initialConfig));
         checkNeedsSave();
     });
@@ -114,18 +101,10 @@ bool ConfigHandler::shouldTestNewSettings()
 
 void ConfigHandler::checkNeedsSave()
 {
-    if (m_config->supportedFeatures() & KScreen::Config::Feature::PrimaryDisplay) {
-        if (m_config->primaryOutput() && m_initialConfig->primaryOutput()) {
-            if (m_config->primaryOutput()->hashMd5() != m_initialConfig->primaryOutput()->hashMd5()) {
-                Q_EMIT needsSaveChecked(true);
-                return;
-            }
-        } else if ((bool)m_config->primaryOutput() != (bool)m_initialConfig->primaryOutput()) {
-            Q_EMIT needsSaveChecked(true);
-            return;
-        }
+    if (checkPrioritiesNeedSave()) {
+        Q_EMIT needsSaveChecked(true);
+        return;
     }
-
     if (m_initialRetention != getRetention()) {
         Q_EMIT needsSaveChecked(true);
         return;
@@ -133,6 +112,33 @@ void ConfigHandler::checkNeedsSave()
     Q_EMIT needsSaveChecked(checkSaveandTestCommon(true));
 }
 
+bool ConfigHandler::checkPrioritiesNeedSave()
+{
+    if (!(m_config->supportedFeatures() & KScreen::Config::Feature::PrimaryDisplay)) {
+        return false;
+    }
+    // first item of pair is initial config, second is current
+    QMap<QString, std::pair<std::optional<uint32_t>, std::optional<uint32_t>>> map;
+
+    // exploiting the fact that operator[] on a map is what's called get_or_insert_default in other languages
+    const auto &initialList = m_initialConfig->outputs();
+    for (const OutputPtr &output : initialList) {
+        map[output->hashMd5()].first = std::optional(output->priority());
+    }
+    const auto &currentList = m_config->outputs();
+    for (const OutputPtr &output : currentList) {
+        map[output->hashMd5()].second = std::optional(output->priority());
+    }
+    // so if we end up with items that are not both initialized to the same priority
+    for (const auto &[left, right] : std::as_const(map)) {
+        if (!(left.has_value() && right.has_value() && left.value() == right.value())) {
+            // then configs must be different after all
+            return true;
+        }
+    }
+    return false;
+}
+
 bool ConfigHandler::checkSaveandTestCommon(bool isSaveCheck)
 {
     const auto outputs = m_config->connectedOutputs();
@@ -222,15 +228,10 @@ void ConfigHandler::checkScreenNormalization()
     Q_EMIT screenNormalizationUpdate(normalized);
 }
 
-void ConfigHandler::primaryOutputSelected(int index)
+void ConfigHandler::outputPrioritiesChanged()
 {
-    Q_UNUSED(index)
-    // TODO
-}
-
-void ConfigHandler::primaryOutputChanged(const KScreen::OutputPtr &output)
-{
-    Q_UNUSED(output)
+    checkNeedsSave();
+    Q_EMIT changed();
 }
 
 Control::OutputRetention ConfigHandler::getRetention() const
@@ -292,16 +293,6 @@ void ConfigHandler::setRetention(int retention)
     Q_EMIT changed();
 }
 
-qreal ConfigHandler::scale(const KScreen::OutputPtr &output) const
-{
-    return m_control->getScale(output);
-}
-
-void ConfigHandler::setScale(KScreen::OutputPtr &output, qreal scale)
-{
-    m_control->setScale(output, scale);
-}
-
 KScreen::OutputPtr ConfigHandler::replicationSource(const KScreen::OutputPtr &output) const
 {
     return m_control->getReplicationSource(output);
